@@ -19,8 +19,9 @@ class Request(object):
     
 
 class Response(object):
-    def __init__(self, code, body, content_type=None):
+    def __init__(self, code, body, content_type=None, location=None):
         self.code = code
         self.body = body
         self.content_type = content_type
+        self.location = location
 
