@@ -29,6 +29,14 @@ def make_task_conf(conf):
                 else:
                     paxd_timeout = None
                 return PRequest(redis, self.queue, args=args, kwds=kwargs, timeout=paxd_timeout).send()
+            @wraps(fun)
+            def run_offline(*args, **kwargs):
+                if 'paxd_timeout' in kwargs:
+                    paxd_timeout = kwargs['paxd_timeout']
+                    del kwargs['paxd_timeout']
+                else:
+                    paxd_timeout = None
+                return PRequest(redis, self.queue, args=args, kwds=kwargs, timeout=paxd_timeout, offline=True).send()
             fun.delay = delay
             fun.paxd_task = True
             fun.paxd_queue = self.queue
